DotSdk class final
IDV SDK main component for initialization and deinitialization.
This class is a singleton, so you can access it via instance getter.
Initialization
Use initialize method for this purpose. In order to check if the SDK is already initialized, use isInitialized method.
Deinitialization
Use deinitialize method for this purpose.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deinitialize(
) → Future< void> - Deinitialize IDV SDK.
-
initialize(
DotSdkConfiguration configuration) → Future< void> - Initialize IDV SDK.
-
isInitialized(
) → Future< bool> - Check if IDV SDK is initialized.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited