deinitialize method
Deinitialize IDV SDK.
When a process (e.g. onboarding) has been completed, it is usually a good practice to free the resources used by it. If you want to use the IDV SDK components again after that point, you need to call initialize again. This shouldn't be performed within the lifecycle of individual IDV SDK components.
Implementation
Future<void> deinitialize() {
return DotCorePlatform.instance.deinitialize();
}